@@ -7,18 +7,17 @@
 #' covariate*group interaction term. 
 #' 
 #'  As input the user provides a formula describing the linear model of how shape (y) varies as a function of a factor (a) 
-#'  or factorial interaction (a*b). A single covariate must also be added.  The shape data (y) 
-#'  must be in the form of a two-dimensional data matrix of dimension (n x [p x k]), rather than a 3D array.  
+#'  or factorial interaction (a*b). A single covariate must also be added.  Shape data (y) can be
+#'  in the form of a two-dimensional data matrix of dimension (n x [p x k]) or a 3D array (p x k x n).  
 #'  It is assumed that the landmarks have previously been aligned using Generalized Procrustes Analysis (GPA)
-#'    [e.g., with \code{\link{gpagen}}]. The function \code{\link{two.d.array}} can be used to
-#'    obtain a two-dimensional data matrix from a 3D array of landmark coordinates.
-#'    From the data, the slopes for each group are estimated, and pairwise differences in slopes determined.
+#'  [e.g., with \code{\link{gpagen}}]. From the data, the slopes for each group are estimated, and pairwise differences 
+#'  in slopes determined.
 #'   
 #'   It is assumed that one has verified a significant group*covariate interaction [e.g., with \code{\link{procD.lm}}].
 #'   To evaluate significance of the pairwise differences, two possible resampling procedures are provided. First, if 
 #'   RRPP=FALSE, the rows of the matrix of shape variables are randomized relative to the design matrix. This is 
 #'   analogous to a 'full' randomization. Second, if RRPP=TRUE, a residual randomization permutation procedure 
-#'   is utilized (Collyer et al. 2014). Here, residual shape values from a reduced model are
+#'   is utilized (Collyer et al. 2015). Here, residual shape values from a reduced model are
 #'   obtained, and are randomized with respect to the linear model under consideration. These are then added to 
 #'   predicted values from the remaining effects to obtain pseudo-values from which SS are calculated. NOTE: for
 #'   single-factor designs, the two approaches are identical.  However, when evaluating factorial models it has been
@@ -61,7 +60,7 @@
 #' ### MANCOVA example for Goodall's F test (multivariate shape vs. factors)
 #' data(plethodon) 
 #' Y.gpa<-gpagen(plethodon$land)    #GPA-alignment    
-#' y<-two.d.array(Y.gpa$coords)
+#' y <- Y.gpa$coords
 #' 
 #' ## Pairwise slope vector correlations
 #' pairwise.slope.test(y~plethodon$site, ~ Y.gpa$Csize, iter=24, angle.type="r")
@@ -72,13 +71,14 @@
 #' ## Using RRPP
 #' pairwise.slope.test(y~plethodon$site, ~Y.gpa$Csize, iter=24, angle.type="rad", RRPP=TRUE)
 pairwise.slope.test <- function (f1, f2, iter = 999, int.first = FALSE, angle.type = c("r", "deg", "rad"), RRPP = FALSE){
-  f1 <- formula(f1)
+  f1 <- as.formula(f1)
+  Y <- eval(f1[[2]], parent.frame())
+  if(length(dim(Y)) == 3)  Y <- two.d.array(Y) else Y <- as.matrix(Y)
+  f1 <- as.formula(paste(c("Y",f1[[3]]),collapse="~"))
   fac.mf <- model.frame(f1)
   angle.type = match.arg(angle.type)
   if(int.first == TRUE) ko = TRUE else ko = FALSE
   Terms <- terms(f1, keep.order = ko)
-  Y <- as.matrix(fac.mf[1])
-  if (length(dim(Y)) != 2) stop("Response matrix (shape) not a 2D array. Use 'two.d.array' first.")
   if (any(is.na(Y)) == T) stop("Response data matrix (shape) contains missing values. Estimate these first (see 'estimate.missing').")
   Xfacs <- model.matrix(Terms)
   newfac <- single.factor(f1, keep.order = ko)
@@ -89,7 +89,7 @@ pairwise.slope.test <- function (f1, f2, iter = 999, int.first = FALSE, angle.ty
   
   cov.mf <- model.frame(as.formula(f2))
   if(length(attr(terms(cov.mf),"term.labels")) > 1) stop("Pairwise comparisons of slopes can only be considered for a single covariate. \n Use advanced.procD.lm for multiple covariates or complex model designs.")
-  Xs <- mod.mats.w.cov(fac.mf, cov.mf, keep.order=ko, interaction = TRUE)
+  Xs <- mod.mats.w.cov(f1=f1, f2=f2, dat1=fac.mf, dat2=cov.mf, keep.order=ko, interaction = TRUE)
   k <- length(Xs$Xs) - 1
   X <- Xs$Xs[[k+1]]
   anova.parts.obs <- anova.parts(f1, X = Xs,Yalt = "observed", keep.order=ko)
@@ -138,4 +138,4 @@ pairwise.slope.test <- function (f1, f2, iter = 999, int.first = FALSE, angle.ty
     list(anova.table=anova.tab, Slope.lengths = slope.lengths, Prob.slope.length = Prob.slope.length, 
          Slope.dist = db, Prob.dist = Prob.dist, Slope.cor = cb, Prob.cor = Prob.cor)
   } else list(anova.table=anova.tab, Slope.lengths = slope.lengths, Prob.slope.length = Prob.slope.length, Slope.dist = db, Prob.dist = Prob.dist, Slope.angle = cb, Prob.angle = Prob.cor)
-}
\ No newline at end of file
+}
