@@ -6,13 +6,15 @@
 #' The function quantifies the relative amount of shape variation attributable to one or more factors in a 
 #'   linear model and assesses this variation via permutation. Data input is specified by a formula (e.g., 
 #'   y~X), where 'y' specifies the response variables (shape data), and 'X' contains one or more independent 
-#'   variables (discrete or continuous). The response matrix 'y' must be in the form of a two-dimensional data 
-#'   matrix of dimension (n x [p x k]), rather than a 3D array.  It is assumed that the landmarks have previously 
-#'   been aligned using Generalized Procrustes Analysis (GPA) [e.g., with \code{\link{gpagen}}]. The function
-#'   \code{\link{two.d.array}} can be used to obtain a two-dimensional data matrix from a 3D array of landmark
-#'   coordinates. The names specified for the independent (x) variables in the formula represent one or more 
+#'   variables (discrete or continuous). The response matrix 'y' can be either in the form of a two-dimensional data 
+#'   matrix of dimension (n x [p x k]), or a 3D array (p x n x k).  It is assumed that the landmarks have previously 
+#'   been aligned using Generalized Procrustes Analysis (GPA) [e.g., with \code{\link{gpagen}}]. 
+#'   The names specified for the independent (x) variables in the formula represent one or more 
 #'   vectors containing continuous data or factors. It is assumed that the order of the specimens in the 
 #'   shape matrix matches the order of values in the independent variables.
+#'   
+#'   The function \code{\link{two.d.array}} can be used to obtain a two-dimensional data matrix from a 3D array of landmark
+#'   coordinates; however this step is no longer necessary, as procD.lm can receive 3D arrays as depedendent variables.
 #'
 #'   The function performs statistical assessment of the terms in the model using Procrustes distances among 
 #'   specimens, rather than explained covariance matrices among variables. With this approach, the sum-of-squared 
@@ -54,36 +56,31 @@
 #' ### MANOVA example for Goodall's F test (multivariate shape vs. factors)
 #' data(plethodon) 
 #' Y.gpa<-gpagen(plethodon$land)    #GPA-alignment    
-#' y<-two.d.array(Y.gpa$coords)
 #'
-#' procD.lm(y~plethodon$species*plethodon$site,iter=99)
+#' procD.lm(Y.gpa$coords ~ plethodon$species*plethodon$site,iter=99)
 #'
 #' ### Regression example
 #' data(ratland)
 #' rat.gpa<-gpagen(ratland)         #GPA-alignment
 #'
-#' procD.lm(two.d.array(rat.gpa$coords)~rat.gpa$Csize,iter=99)
+#' procD.lm(rat.gpa$coords ~ rat.gpa$Csize,iter=99)
 #' 
 #' ## using RRPP
-#'  procD.lm(two.d.array(rat.gpa$coords)~rat.gpa$Csize,iter=49,RRPP=TRUE)
+#'  procD.lm(rat.gpa$coords ~ rat.gpa$Csize,iter=49,RRPP=TRUE)
 procD.lm <- function(f1, iter = 999, RRPP = FALSE, int.first = FALSE, verbose=FALSE){
   form.in <- formula(f1)
-  mod.mf <- model.frame(form.in)
+  Y <- eval(form.in[[2]], parent.frame())
+  if(length(dim(Y)) == 3)  Y <- two.d.array(Y) else Y <- as.matrix(Y)
+  if(nrow(Y) != nrow(model.frame(form.in[-2]))) stop("Different numbers of specimens in dependent and independent variables")
+  form.new <- as.formula(paste(c("Y",form.in[[3]]),collapse="~"))
   if(int.first == TRUE) ko = TRUE else ko = FALSE
-  Terms <- terms(form.in, keep.order = ko)
-  Y <- as.matrix(eval(form.in[[2]], parent.frame()))
-  if (length(dim(Y)) != 2) {
-    stop("Response matrix (shape) not a 2D array. Use 'two.d.array' first.")
-  }	
-  if (any(is.na(Y)) == T) {
-    stop("Response data matrix (shape) contains missing values. Estimate these first (see 'estimate.missing').")
-  }
-  if (is.null(dimnames(Y)[[1]])) {
-    print("No specimen names in response matrix. Assuming specimens in same order.")
-  }
-  anova.parts.obs <- anova.parts(form.in, Yalt = "observed", keep.order=ko)
+  Terms <- terms(form.new, keep.order = ko)
+  mod.mf <- model.frame(Terms)
+  if (any(is.na(Y)) == T) stop("Response data matrix (shape) contains missing values. Estimate these first (see 'estimate.missing').")
+
+  anova.parts.obs <- anova.parts(f1 = form.new, Yalt = "observed", keep.order=ko)
   anova.tab <-anova.parts.obs$table  
-  Xs <- mod.mats(mod.mf, keep.order=ko)
+  Xs <- mod.mats(form.new, mod.mf, keep.order=ko)
   k <- length(Xs$Xs) - 1
   P <-array(0, c(k, 1, iter+1))
   SS.obs <-anova.parts.obs$SS[1:k]
@@ -105,4 +102,4 @@ procD.lm <- function(f1, iter = 999, RRPP = FALSE, int.first = FALSE, verbose=FA
   if(verbose==TRUE)  {
     list(anova.table = anova.tab, call=match.call(), SS.rand = P)
   } else anova.tab
-}
\ No newline at end of file
+}
